@@ -82,7 +82,8 @@ class AzureMLLunaUtils(BaseLunaUtils):
                 'deploymentName': self._args.deploymentName, 
                 'apiVersion':self._args.apiVersion,
                 'subscriptionId':self._args.subscriptionId,
-                'modelId': self._args.predecessorOperationId})
+                'modelId': self._args.predecessorOperationId,
+                'endpointId': self._args.operationId})
         
         service = Model.deploy(ws, self._args.predecessorOperationId, [model], inference_config, deployment_config)
         service.wait_for_deployment(show_output = True)
