@@ -17,6 +17,7 @@ class BaseLunaUtils(object):
         self._run_mode = run_mode
         self._args= args
         self._userInput = userInput
+        self._logger = None
 
     @property
     def luna_config(self):
@@ -31,9 +32,13 @@ class BaseLunaUtils(object):
         return self._args
 
     @property
-    def userInput(self):
+    def user_input(self):
         return self._userInput
 
+    @property
+    def logger(self):
+        return self._logger
+
     @abstractmethod
     def RegisterModel(self, model_path, description, luna_python_model=None):
         """
