@@ -16,6 +16,6 @@ class AzureMLLunaLogger(BaseLunaLogger):
     def upload_artifacts(self, local_path, upload_path):
         run = Run.get_context(allow_offline=False)
         if os.path.isdir(local_path):
-            run.upload_folder(local_path, upload_path)
+            run.upload_folder(upload_path, local_path)
         elif os.path.isfile(local_path):
-            run.upload_file(local_path, upload_path)
\ No newline at end of file
+            run.upload_file(upload_path, local_path)
\ No newline at end of file
